package category

import (
	"github.com/gin-gonic/gin"
	"net/http"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type CreateCategoryResponse struct {
	Name             string `json:"name" binding:"required"`
	Description      string `json:"description"`
	ParentCategoryID int64  `json:"parent_category_id" binding:"required"`
	Level            int64  `json:"level" binding:"required"`
	ImageURL         string `json:"image_url"`
}

// CreateCategory
// @summary 新增
// @Tags 分类管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param body body CreateCategoryResponse true "请求body"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/category [post]
func (svc *Category) CreateCategory(c *gin.Context) {
	var req CreateCategoryResponse
	if err := c.ShouldBindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingCategoryService.CreateCategory")
	_, err := svc.Service.CreateCategory(ctx, &pb.CreateCategoryRequest{
		Name:             req.Name,
		ParentCategoryId: req.ParentCategoryID,
		Description:      req.Description,
		ImageUrl:         req.ImageURL,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
