package permission

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/common"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type CreatePermissionRequest struct {
	Name        string  `json:"name" binding:"required"`     // 用户名
	Description string  `json:"description"`                 // 描述
	Endpoint    string  `json:"endpoint" binding:"required"` // API
	Roles       []int64 `json:"roles"`
}

// CreatePermission
// @summary 新增权限项
// @Tags 权限项管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param body body CreatePermissionRequest true "请求body"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/permission [post]
func (svc *Permission) CreatePermission(c *gin.Context) {
	var req CreatePermissionRequest
	if err := c.ShouldBindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	if isBool, err := common.ValidateNumericInt64(req.Roles); !isBool {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingPermissionService.CreatePermission")
	_, err := svc.Service.CreatePermission(ctx, &pb.CreatePermissionRequest{
		Name:        req.Name,
		Description: req.Description,
		Endpoint:    req.Endpoint,
		Roles:       req.Roles,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
