package permission

import (
	"github.com/gin-gonic/gin"
	"net/http"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

// DeletePermission
// @summary 删除
// @Tags 权限项管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "权限项 ID"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/permission/{permission_id} [delete]
func (svc *Permission) DeletePermission(c *gin.Context) {
	permissionID, err := strconv.ParseInt(c.Param("permission_id"), 10, 64)
	if err != nil || permissionID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, "Invalid permissionID"))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingPermissionService.DeletePermission")
	_, err = svc.Service.DeletePermission(ctx, &pb.DeletePermissionRequest{
		PermissionId: permissionID,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
