package permission

import (
	"sghgogs.com/micro/shopping-service-client/domain/model/base"
	model_res "sghgogs.com/micro/shopping-service-client/domain/model/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"time"
)

type Permission struct {
	Service   pb.ShoppingPermissionService
	Namespace string
}

func (svc *Permission) getPermissionsRes(permissions []*pb.Permission) []model_res.Permission {
	items := make([]model_res.Permission, 0)

	for _, permission := range permissions {
		items = append(items, svc.getPermissionRes(*permission))
	}
	return items
}

func (svc *Permission) getPermissionRes(permission pb.Permission) model_res.Permission {
	toStatus, _ := base.MapEnumToStatus(permission.Status)
	var unix time.Time
	if permission.UpdatedAt > 0 {
		unix = utils.ConvertInt64ToTime(permission.CreatedAt)
	}
	return model_res.Permission{
		ID:          permission.Id,
		Name:        permission.Name,
		Endpoint:    permission.Endpoint,
		Description: permission.Description,
		CreatedAt:   utils.ConvertInt64ToTime(permission.CreatedAt),
		CreatedBy:   permission.CreatedBy,
		UpdatedAt:   &unix,
		UpdatedBy:   permission.UpdatedBy,
		Status:      toStatus,
		IsReserved:  permission.IsReserved,
	}
}
