package product

import (
	"github.com/gin-gonic/gin"
	"net/http"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type CreateProductRequest struct {
	Name          string `json:"name" binding:"required"`           // 商品名称
	Description   string `json:"description"`                       // 商品描述
	Price         int64  `json:"price" binding:"required"`          // 商品价格
	StockQuantity int32  `json:"stock_quantity" binding:"required"` // 库存数量
	CategoryID    int64  `json:"category_id" binding:"required"`    // 分类ID
	ImageURL      string `json:"image_url" binding:"required"`      // 商品图片
}

// CreateProduct
// @summary 新增
// @Tags 商品管理
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param body body CreateProductRequest true "请求body"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/product [post]
func (svc *Product) CreateProduct(c *gin.Context) {
	var req CreateProductRequest
	if err := c.ShouldBindJSON(&req); err != nil {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, err.Error()))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingProductService.CreateProduct")
	_, err := svc.Service.CreateProduct(ctx, &pb.CreateProductRequest{
		Items: []*pb.Product{
			{
				Name:          req.Name,
				Description:   req.Description,
				Price:         req.Price,
				StockQuantity: req.StockQuantity,
				CategoryId:    req.CategoryID,
				ImageUrl:      req.ImageURL,
			},
		},
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
