package role

import (
	"github.com/gin-gonic/gin"
	"net/http"
	"sghgogs.com/micro/common"
	res "sghgogs.com/micro/shopping-service-client/response"
	"sghgogs.com/micro/shopping-service-client/utils"
	pb "sghgogs.com/micro/shopping-service-service/proto"
	"strconv"
)

// DeleteRole
// @summary 删除
// @Tags 角色管理 Roles
// @Accept json
// @Produce json
// @Param Authorization header string true "Bearer 用户令牌"
// @Param    id   path      int  true  "角色 ID"
// @Success 200 {object} response.ApiResponse "成功"
// @Failure 400 {object} response.ApiResponse "请求错误"
// @Failure 500 {object} response.ApiResponse "内部错误"
// @Router /admin/v1/api/role/{role_id} [delete]
func (svc *Role) DeleteRole(c *gin.Context) {
	roleID, err := strconv.ParseInt(c.Param("role_id"), 10, 64)
	if err != nil || roleID <= 0 {
		c.JSON(http.StatusBadRequest, res.ErrorResponse(http.StatusBadRequest, common.ErrorMessage[common.InvalidRoleID]))
		return
	}
	ctx, _ := utils.CreateContextWithToken(c, svc.Namespace, "ShoppingRoleService.DeleteRole")
	_, err = svc.Service.DeleteRole(ctx, &pb.DeleteRoleRequest{
		RoleId: roleID,
	})
	if err != nil {
		code, mgs := res.MicroErrorRequest(err)
		c.JSON(code, res.ErrorResponse(code, mgs))
		return
	}
	c.JSON(http.StatusOK, res.SuccessResponse(nil))
}
