package auth

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/auth"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type Auth struct {
	*baseservice.BaseService
}

func NewAuthRouter(namespace string, client client.Client) *Auth {
	return &Auth{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}

func (svc *Auth) RegisterRoutes(r *gin.Engine) {
	api := auth.Auth{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingAuthService(svc.Namespace, svc.Client)
	svc.registerAuthRoutes(r, "/admin/v1/api", &api)
}

func (svc *Auth) registerAuthRoutes(r *gin.Engine, path string, api *auth.Auth) {
	v1 := r.Group(path)
	{
		v1.POST("/login", api.Login)
		v1.GET("/profile", utils.TokenAuthMiddleware(), api.GetProfile)
		v1.POST("/logout", utils.TokenAuthMiddleware(), api.Logout)
	}
}
