package order

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/order"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type Order struct {
	*baseservice.BaseService
}

func NewOrderRouter(namespace string, client client.Client) *Order {
	return &Order{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}
func (svc *Order) RegisterRoutes(r *gin.Engine) {
	api := order.Order{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingOrderService(svc.Namespace, svc.Client)
	svc.registerOrderRoutes(r, "/admin/v1/api", &api)
}
func (svc *Order) registerOrderRoutes(r *gin.Engine, path string, api *order.Order) {
	v1 := r.Group(path).Use(utils.TokenAuthMiddleware())
	{
		v1.GET("/orders", api.GetOrderList)                                        // 获取订单列表
		v1.GET("/order/:order_id", api.GetOrder)                                   // 获取订单项详情
		v1.POST("/order/:order_id/confirm_processing", api.ConfirmOrderProcessing) // 处理中
		v1.POST("/order/:order_id/delivery", api.InitiateShipping)                 // 发货中
		v1.POST("/order/:order_id/complete_delivery", api.CompleteDelivery)        // 完成
	}
}
