package product

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/product"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type Product struct {
	*baseservice.BaseService
}

func NewProductRouter(namespace string, client client.Client) *Product {
	return &Product{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}
func (svc *Product) RegisterRoutes(r *gin.Engine) {
	api := product.Product{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingProductService(svc.Namespace, svc.Client)
	svc.registerRoleRoutes(r, "/admin/v1/api", &api)
}
func (svc *Product) registerRoleRoutes(r *gin.Engine, path string, api *product.Product) {
	v1 := r.Group(path).Use(utils.TokenAuthMiddleware())
	{
		v1.GET("/products", api.GetProductList)
		v1.GET("/product/:product_id", api.GetProduct)
		v1.POST("/product", api.CreateProduct)
		v1.PUT("product/:product_id", api.UpdateProduct)
		v1.DELETE("product/:product_id", api.DeleteProduct)
	}
}
