package user

import (
	"github.com/gin-gonic/gin"
	"go-micro.dev/v4/client"
	"sghgogs.com/micro/shopping-service-client/api/user"
	"sghgogs.com/micro/shopping-service-client/utils"
	"sghgogs.com/micro/shopping-service-client/utils/baseservice"
	pb "sghgogs.com/micro/shopping-service-service/proto"
)

type User struct {
	*baseservice.BaseService
}

func NewUserRouter(namespace string, client client.Client) *User {
	return &User{
		BaseService: &baseservice.BaseService{
			Namespace: namespace,
			Client:    client,
		},
	}
}
func (svc *User) RegisterRoutes(r *gin.Engine) {
	api := user.User{}
	api.Namespace = svc.Namespace
	api.Service = pb.NewShoppingUserService(svc.Namespace, svc.Client)
	svc.registerUserAdminRoutes(r, "/admin/v1/api", &api)
}

func (svc *User) registerUserAdminRoutes(r *gin.Engine, path string, api *user.User) {
	v1 := r.Group(path).Use(utils.TokenAuthMiddleware())
	{
		v1.GET("/users", api.GetUserList)
		v1.GET("/user/:user_id", api.GetUser)
		v1.PUT("/user/:user_id", api.UpdateUser)
		v1.PUT("/user/:user_id/toggle", api.ToggleRole)
		v1.POST("/user", api.CreateUser)
		v1.DELETE("/user/:user_id", api.DeleteUser)
	}
}
